SEO.Breadcrumb (SEO v0.2.1)

Copy Markdown View Source

This is SEO for Google to display breadcrumbs in the search results. This allows the search result to search as multiple links.

Breadcrumb Example

Resources

Rendered example inside a <script type="application/ld+json">:

{
  "@context": "https://schema.org",
  "@type": "BreadcrumbList",
  "itemListElement": [{
    "@type": "ListItem",
    "item": "https://bernheisel.com/blog",
    "name": "Posts",
    "position": 1
  },{
    "@type": "ListItem",
    "item": "https://bernheisel.com/blog/nostalgia-programming",
    "name": "Nostalgia, Fun, and Programming",
    "position": 2
  }]
}

Summary

Functions

meta(assigns)

Attributes